FutureResultX<T> extension

Extension on standard Dart Future blocks to seamlessly encapsulate raw asynchronous processing scopes directly into safe functional Result pipelines.

on

Methods

toResult() Future<Result<T>>

Available on Future<T>, provided by the FutureResultX extension

Catches any unhandled exceptions during the execution lifecycle of the host Future and automatically maps the outcome into a type-safe Result object.