core/extensions/future_retry_extensions library
Extensions
-
FutureRetryExtension
on Future<
T> Function() - Extension on Future functions to transparently intercept runtime execution and perform recovery retries before wrapping the final outcome into a Result pipeline.