FutureRetryExtension<T> extension

Extension on Future functions to transparently intercept runtime execution and perform recovery retries before wrapping the final outcome into a Result pipeline.

on

Methods

withRetry([RetryOptions options = const RetryOptions()]) Future<T>

Available on Future<T> Function(), provided by the FutureRetryExtension extension

Executes the underlying future operation with a structured retry mechanism.