ResultZip2RecordX<T1, T2> extension

Extension on a 2-element Record of Result instances to allow direct, non-static zipping syntax.

on

Methods

zip<R>(R combiner(T1 v1, T2 v2)) Result<R>

Available on (Result<T1>, Result<T2>), provided by the ResultZip2RecordX extension

Zips two disparate results into a single consolidated Result.