VoidResult typedef

VoidResult = Result<Unit>

A highly expressive type alias representing an operation that completes with zero return data but can still implicitly fail.

Implementation

typedef VoidResult = Result<Unit>;