menu
resultex package
documentation
core/utils/result_collection.dart
ResultCollection class
ResultCollection class
dark_mode
light_mode
ResultCollection
class
Constructors
ResultCollection
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Static Methods
mapList
<
I
,
O
>
(
List
<
I
>
list
,
Result
<
O
>
mapper
(
I
item
), {
bool
strict
=
true
})
→
Result
<
List
<
O
>
>
Iterates over a
list
of elements, applies a transformation function
mapper
that returns a
Result
, and aggregates the outcomes based on the selected
strict
strategy.
resultex package
documentation
core/utils/result_collection
ResultCollection class
result_collection library