ResultMemoizer class

Architectural utility for caching functional evaluations.

Constructors

ResultMemoizer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

memoizeAsync<T>(Future<Result<T>> computation()) Future<Result<T>> Function()
Wraps an asynchronous computation, returning a memoized version of the function.