ResultUtils class abstract

Utility methods for managing and aggregating multiple Result instances.

Constructors

ResultUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

combineAll<T>(List<Future<Result<T>>> futures) Future<Result<List<T>>>
Executes multiple Future<Result> operations in parallel and aggregates their outcomes.