invoke abstract method

Future<Result> invoke(
  1. Params params
)

Executes the core business logic of the use case.

Takes the necessary input params and returns a Future containing the Result.

Implementation

Future<Result> invoke(Params params);