operator == method

  1. @override
bool operator ==(
  1. Object other
)

Compares two Failure instances based on their value states rather than memory addresses.

Excludes stackTrace from equality logic as identical errors can possess unique traces.

Implementation

@override
bool operator ==(Object other) =>
    identical(this, other) ||
    other is Failure && message == other.message && error == other.error;