lib/src/model/result library

Classes

Result<T>
A sealed monadic wrapper representing the outcome of an operation that can either be a successful evaluation (_SuccessResult) or a structural breakdown (_FailureResult).