isSuccess property
bool
get
isSuccess
Evaluates true if this runtime instance encapsulates an underlying successful operation outcome.
Implementation
bool get isSuccess => this is _SuccessResult<T>;
Evaluates true if this runtime instance encapsulates an underlying successful operation outcome.
bool get isSuccess => this is _SuccessResult<T>;