ResultExecutorModule class
A dependency injection module responsible for registering the ResultExecutor.
This module handles the registration of the execution wrapper, ensuring it has access to the central logging system for monitoring results and side-effects.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
GetIt injector) → void -
Registers the ResultExecutor into the
GetItinjector container.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited