core/utils/cancellable_result library
Classes
-
CancellableResult<
T> - A reactive wrapper for asynchronous operations that can be manually aborted.
Extensions
- ResultCancellationX on Result
- Extension to easily instantiate a cancellable operation from the core namespace.