CancellableResult<T> class
A reactive wrapper for asynchronous operations that can be manually aborted.
Constructors
-
CancellableResult(Future<
Result< computation())T> >
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancelled → bool
-
Whether the cancel method has been triggered.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ Future<
Result< T> > -
The underlying reactive future. Consumers should await this property.
no setter
Methods
-
cancel(
[String? customMessage]) → void - Instantly aborts the operational pipeline.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited