ResultCollection class

Constructors

ResultCollection()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

mapList<I, O>(List<I> list, Result<O> mapper(I item), {bool strict = true}) Result<List<O>>
Iterates over a list of elements, applies a transformation function mapper that returns a Result, and aggregates the outcomes based on the selected strict strategy.