UseCase<Result, Params> class
abstract
An abstract representation of a single business logic execution unit (Use Case / Interactor).
This contract follows the Clean Architecture pattern, isolating domain logic from presentation or data layer implementations. Each use case is responsible for executing exactly one specific feature or action.
Result The type of data returned asynchronously upon successful execution.
Params The wrapper object containing all required inputs to execute this use case.
Constructors
- UseCase()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
invoke(
Params params) → Future< Result> - Executes the core business logic of the use case.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited